extract_thread_root

Function extract_thread_root 

pub fn extract_thread_root(
    event: &Raw<AnySyncTimelineEvent>,
) -> Option<OwnedEventId>
Try to extract the thread root from a timeline event, if provided.

The thread root is the field located at "content"."m.relates_to"."event_id", if the field at "content"."m.relates_to"."rel_type" is m.thread.

Returns None if we couldn’t find a thread root, or if there was an issue during deserialization.